



# Critical Photon OS Security Update

## Summary

Advisory Id     : PHSA-2023-4.0-0500

Type            : Security

Severity        : ['Critical', 'Low']

Issue date      : 2023-10-11

Affected Release: 4.0

## Details

Updates of ['curl'] packages of Photon OS have been released.
## Affected Packages

### Critical

curl - ['[CVE-2023-38545](https://nvd.nist.gov/vuln/detail/CVE-2023-38545)']

### Low

curl - ['[CVE-2023-38546](https://nvd.nist.gov/vuln/detail/CVE-2023-38546)']

curl-libs - ['[CVE-2023-38546](https://nvd.nist.gov/vuln/detail/CVE-2023-38546)']

## Solution

Update the affected packages (tdnf update package)
